/* intrin.def -- Public #include File (module.h template V1.0)
   Copyright (C) 1995 Free Software Foundation, Inc.
   Contributed by James Craig Burley (burley@gnu.ai.mit.edu).

This file is part of GNU Fortran.

GNU Fortran is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Fortran is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Fortran; see the file COPYING.  If not, write to
the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

   Owning Modules:
      intrin.c

   Modifications:
*/

/* Throughout this file, g77 internal codes often use the following
   letters to mean the following types:

   I -- INTEGER*4
   J -- INTEGER*2
   K -- INTEGER*1
   R -- REAL*4
   D -- REAL*8
   Q -- REAL*16
   C -- COMPLEX*8
   E -- COMPLEX*16
   F -- COMPLEX*32
   A -- CHARACTER
   L -- LOGICAL*4
   M -- LOGICAL*2
   N -- LOGICAL*1
   B -- Boolean (INTEGER or LOGICAL)

   Note that the above aren't blessed by any standard, and conflict
   in some ways with various popular compilers (e.g. VAX/VMS FORTRAN
   switches I and J; f2c/f77 uses Z instead of E).  But it makes sense
   to pick one naming convention for internal use and stick to it, and
   have intrinsic-name and library-name issues be separate.

   FFEINTRIN_genXYZZY and FFEINTRIN_specXYZZY are keywords referring
   to XYZZY as external (i.e. user-visible) names, while FFEINTRIN_gen_XYZZY,
   FFEINTRIN_spec_XYZZY, and FFEINTRIN_impXYZZY all are keywords referring
   to XYZZY as g77-internal and thus XYZZY is named according to the
   above mapping.

   So the keyword FFEINTRIN_specJFOO refers to some language's definition
   of JFOO, thus that language's use of J prevails for that keyword
   (e.g. for VAX FORTRAN, it means INTEGER*4), whereas the keyword
   FFEINTRIN_spec_JFOO_C, being an internal name, refers to g77's
   definition of _JFOO_C, thus it means it's a FOO taking COMPLEX args
   and returning INTEGER*2.  Sigh.  Being compatible is really annoying!  */

/* Generic intrinsics listed in any order.
   This list corresponds to the names of generic intrinsics as seen
   in source code, and should thus be consulted only when an intrinsic
   invocation of the form "MAYBEGENERIC(...)" or "INTRINSIC MAYBEGENERIC"
   is seen.  */

DEFGEN (FFEINTRIN_genABS, "ABS",
    FFEINTRIN_specIABS,
    FFEINTRIN_specABS,
    FFEINTRIN_specDABS,
    FFEINTRIN_specCABS,
    FFEINTRIN_specIIABS,
    FFEINTRIN_specJIABS,
    FFEINTRIN_specQABS,
    FFEINTRIN_specCDABS,
    FFEINTRIN_specZABS,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genACOS, "ACOS",
    FFEINTRIN_specACOS,
    FFEINTRIN_specDACOS,
    FFEINTRIN_specQACOS,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genAINT, "AINT",
    FFEINTRIN_specAINT,
    FFEINTRIN_specDINT,
    FFEINTRIN_specQINT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genANINT, "ANINT",
    FFEINTRIN_specANINT,
    FFEINTRIN_specDNINT,
    FFEINTRIN_specQNINT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genASIN, "ASIN",
    FFEINTRIN_specASIN,
    FFEINTRIN_specDASIN,
    FFEINTRIN_specQASIN,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genATAN, "ATAN",
    FFEINTRIN_specATAN,
    FFEINTRIN_specDATAN,
    FFEINTRIN_specQATAN,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genATAN2, "ATAN2",
    FFEINTRIN_specATAN2,
    FFEINTRIN_specDATAN2,
    FFEINTRIN_specQATAN2,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genCMPLX, "CMPLX",
    FFEINTRIN_spec_CMPLX_I,
    FFEINTRIN_spec_CMPLX_R,
    FFEINTRIN_spec_CMPLX_D,
    FFEINTRIN_spec_CMPLX_C,
    FFEINTRIN_spec_CMPLX_J,
    FFEINTRIN_spec_CMPLX_Q,
    FFEINTRIN_spec_CMPLX_E,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genCOS, "COS",
    FFEINTRIN_specCOS,
    FFEINTRIN_specDCOS,
    FFEINTRIN_specCCOS,
    FFEINTRIN_specQCOS,
    FFEINTRIN_specCDCOS,
    FFEINTRIN_specZCOS,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genCOSH, "COSH",
    FFEINTRIN_specCOSH,
    FFEINTRIN_specDCOSH,
    FFEINTRIN_specQCOSH,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genDBLE, "DBLE",
    FFEINTRIN_spec_DBLE_I,
    FFEINTRIN_spec_DBLE_R,
    FFEINTRIN_spec_DBLE_D,
    FFEINTRIN_spec_DBLE_C,
    FFEINTRIN_spec_DBLE_J,
    FFEINTRIN_specDBLEQ,
    FFEINTRIN_spec_DBLE_E,
    FFEINTRIN_specDBLE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genDIM, "DIM",
    FFEINTRIN_specIDIM,
    FFEINTRIN_specDIM,
    FFEINTRIN_specDDIM,
    FFEINTRIN_specIIDIM,
    FFEINTRIN_specJIDIM,
    FFEINTRIN_specQDIM,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genEXP, "EXP",
    FFEINTRIN_specEXP,
    FFEINTRIN_specDEXP,
    FFEINTRIN_specCEXP,
    FFEINTRIN_specQEXP,
    FFEINTRIN_specCDEXP,
    FFEINTRIN_specZEXP,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genIABS, "IABS",
    FFEINTRIN_specIABS,
    FFEINTRIN_specIIABS,
    FFEINTRIN_specJIABS,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genINT, "INT",
    FFEINTRIN_spec_INT_I,
    FFEINTRIN_specINT,
    FFEINTRIN_specIDINT,
    FFEINTRIN_spec_INT_C,
    FFEINTRIN_specIINT,
    FFEINTRIN_specJINT,
    FFEINTRIN_specIIDINT,
    FFEINTRIN_specJIDINT,
    FFEINTRIN_specIIQINT,
    FFEINTRIN_specJIQINT,
    FFEINTRIN_spec_JINT_C,
    FFEINTRIN_spec_IINT_C,
    FFEINTRIN_spec_JINT_E,
    FFEINTRIN_spec_IINT_E
  )
DEFGEN (FFEINTRIN_genLOG, "LOG",
    FFEINTRIN_specALOG,
    FFEINTRIN_specDLOG,
    FFEINTRIN_specCLOG,
    FFEINTRIN_specQLOG,
    FFEINTRIN_specCDLOG,
    FFEINTRIN_specZLOG,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genLOG10, "LOG10",
    FFEINTRIN_specALOG10,
    FFEINTRIN_specDLOG10,
    FFEINTRIN_specQLOG10,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMAX, "MAX",
    FFEINTRIN_specMAX0,
    FFEINTRIN_specAMAX1,
    FFEINTRIN_specDMAX1,
    FFEINTRIN_specIMAX0,
    FFEINTRIN_specJMAX0,
    FFEINTRIN_specQMAX1,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMIN, "MIN",
    FFEINTRIN_specMIN0,
    FFEINTRIN_specAMIN1,
    FFEINTRIN_specDMIN1,
    FFEINTRIN_specIMIN0,
    FFEINTRIN_specJMIN0,
    FFEINTRIN_specQMIN1,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMOD, "MOD",
    FFEINTRIN_specMOD,
    FFEINTRIN_specAMOD,
    FFEINTRIN_specDMOD,
    FFEINTRIN_specIMOD,
    FFEINTRIN_specJMOD,
    FFEINTRIN_specQMOD,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMVBITS, "MVBITS",
    FFEINTRIN_specMVBITS,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genNINT, "NINT",
    FFEINTRIN_specNINT,
    FFEINTRIN_specIDNINT,
    FFEINTRIN_specININT,
    FFEINTRIN_specJNINT,
    FFEINTRIN_specIIDNNT,
    FFEINTRIN_specJIDNNT,
    FFEINTRIN_specIIQNNT,
    FFEINTRIN_specJIQNNT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genREAL, "REAL",
    FFEINTRIN_specREAL,
    FFEINTRIN_specFLOAT,
    FFEINTRIN_spec_REAL_R,
    FFEINTRIN_specSNGL,
    FFEINTRIN_spec_REAL_C,
    FFEINTRIN_specFLOATI,
    FFEINTRIN_specFLOATJ,
    FFEINTRIN_specSNGLQ,
    FFEINTRIN_spec_REAL_E,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genSIGN, "SIGN",
    FFEINTRIN_specISIGN,
    FFEINTRIN_specSIGN,
    FFEINTRIN_specDSIGN,
    FFEINTRIN_specIISIGN,
    FFEINTRIN_specJISIGN,
    FFEINTRIN_specQSIGN,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genSIN, "SIN",
    FFEINTRIN_specSIN,
    FFEINTRIN_specDSIN,
    FFEINTRIN_specCSIN,
    FFEINTRIN_specQSIN,
    FFEINTRIN_specCDSIN,
    FFEINTRIN_specZSIN,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genSINH, "SINH",
    FFEINTRIN_specSINH,
    FFEINTRIN_specDSINH,
    FFEINTRIN_specQSINH,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genSQRT, "SQRT",
    FFEINTRIN_specSQRT,
    FFEINTRIN_specDSQRT,
    FFEINTRIN_specCSQRT,
    FFEINTRIN_specQSQRT,
    FFEINTRIN_specCDSQRT,
    FFEINTRIN_specZSQRT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genTAN, "TAN",
    FFEINTRIN_specTAN,
    FFEINTRIN_specDTAN,
    FFEINTRIN_specQTAN,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genTANH, "TANH",
    FFEINTRIN_specTANH,
    FFEINTRIN_specDTANH,
    FFEINTRIN_specQTANH,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genAIMAG, "AIMAG",
    FFEINTRIN_specAIMAG,
    FFEINTRIN_spec_IMAG_E,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genAMAX0, "AMAX0",
    FFEINTRIN_specAMAX0,
    FFEINTRIN_specAIMAX0,
    FFEINTRIN_specAJMAX0,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genAMIN0, "AMIN0",
    FFEINTRIN_specAMIN0,
    FFEINTRIN_specAIMIN0,
    FFEINTRIN_specAJMIN0,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genFLOAT, "FLOAT",
    FFEINTRIN_specFLOAT,
    FFEINTRIN_specFLOATI,
    FFEINTRIN_specFLOATJ,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genIDIM, "IDIM",
    FFEINTRIN_specIDIM,
    FFEINTRIN_specIIDIM,
    FFEINTRIN_specJIDIM,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genIDINT, "IDINT",
    FFEINTRIN_specIDINT,
    FFEINTRIN_specIIDINT,
    FFEINTRIN_specJIDINT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genIDNINT, "IDNINT",
    FFEINTRIN_specIDNINT,
    FFEINTRIN_specIIDNNT,
    FFEINTRIN_specJIDNNT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genIFIX, "IFIX",
    FFEINTRIN_specIFIX,
    FFEINTRIN_specIIFIX,
    FFEINTRIN_specJIFIX,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genIQINT, "IQINT",
    FFEINTRIN_specIIQINT,
    FFEINTRIN_specJIQINT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genIQNINT, "IQNINT",
    FFEINTRIN_specIIQNNT,
    FFEINTRIN_specJIQNNT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMAX0, "MAX0",
    FFEINTRIN_specMAX0,
    FFEINTRIN_specIMAX0,
    FFEINTRIN_specJMAX0,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMAX1, "MAX1",
    FFEINTRIN_specMAX1,
    FFEINTRIN_specIMAX1,
    FFEINTRIN_specJMAX1,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMIN0, "MIN0",
    FFEINTRIN_specMIN0,
    FFEINTRIN_specIMIN0,
    FFEINTRIN_specJMIN0,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMIN1, "MIN1",
    FFEINTRIN_specMIN1,
    FFEINTRIN_specIMIN1,
    FFEINTRIN_specJMIN1,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genACHAR, "ACHAR",	/* F90, F2C */
    FFEINTRIN_specACHAR,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genACOSD, "ACOSD",	/* VXT */
    FFEINTRIN_specACOSD,
    FFEINTRIN_specDACOSD,
    FFEINTRIN_specQACOSD,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genADJUSTL, "ADJUSTL",	/* F90 */
    FFEINTRIN_specADJUSTL,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genADJUSTR, "ADJUSTR",	/* F90 */
    FFEINTRIN_specADJUSTR,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genALL, "ALL",	/* F90 */
    FFEINTRIN_specALL,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genALLOCATED, "ALLOCATED",	/* F90 */
    FFEINTRIN_specALLOCATED,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genAND, "AND",	/* F2C */
    FFEINTRIN_spec_AND_I,
    FFEINTRIN_spec_AND_L,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genANY, "ANY",	/* F90 */
    FFEINTRIN_specANY,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genASIND, "ASIND",	/* VXT */
    FFEINTRIN_specASIND,
    FFEINTRIN_specDASIND,
    FFEINTRIN_specQASIND,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genASSOCIATED, "ASSOCIATED",	/* F90 */
    FFEINTRIN_specASSOCIATED,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genATAN2D, "ATAN2D",	/* VXT */
    FFEINTRIN_specATAN2D,
    FFEINTRIN_specDATAN2D,
    FFEINTRIN_specQATAN2D,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genATAND, "ATAND",	/* VXT */
    FFEINTRIN_specATAND,
    FFEINTRIN_specDATAND,
    FFEINTRIN_specQATAND,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genBIT_SIZE, "BIT_SIZE",	/* F90 */
    FFEINTRIN_specBIT_SIZE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genBTEST, "BTEST",	/* F90, VXT */
    FFEINTRIN_specBTEST,
    FFEINTRIN_specBITEST,
    FFEINTRIN_specBJTEST,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genCEILING, "CEILING",	/* F90 */
    FFEINTRIN_specCEILING,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genCHAR, "CHAR",	/* VXT */
    FFEINTRIN_specCHAR,
    FFEINTRIN_spec_CHAR_N,
    FFEINTRIN_spec_CHAR_J,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genCONJG, "CONJG",	/* VXT */
    FFEINTRIN_specCONJG,
    FFEINTRIN_specDCONJG,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genCOSD, "COSD",	/* VXT */
    FFEINTRIN_specCOSD,
    FFEINTRIN_specDCOSD,
    FFEINTRIN_specQCOSD,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genCOUNT, "COUNT",	/* F90 */
    FFEINTRIN_specCOUNT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genCSHIFT, "CSHIFT",	/* F90 */
    FFEINTRIN_specCSHIFT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genDCMPLX, "DCMPLX",	/* F2C, VXT */
    FFEINTRIN_spec_DCMPLX_J,
    FFEINTRIN_spec_DCMPLX_I,
    FFEINTRIN_spec_DCMPLX_R,
    FFEINTRIN_spec_DCMPLX_D,
    FFEINTRIN_spec_DCMPLX_Q,
    FFEINTRIN_spec_DCMPLX_C,
    FFEINTRIN_spec_DCMPLX_E,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genDFLOAT, "DFLOAT",	/* F2C, VXT */
    FFEINTRIN_specDFLOTI,
    FFEINTRIN_specDFLOTJ,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genDIGITS, "DIGITS",	/* F90 */
    FFEINTRIN_specDIGITS,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genDOT_PRODUCT, "DOT_PRODUCT",	/* F90 */
    FFEINTRIN_specDOT_PRODUCT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genDPROD, "DPROD",	/* F90 */
    FFEINTRIN_specDPROD,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genEOSHIFT, "EOSHIFT",	/* F90 */
    FFEINTRIN_specEOSHIFT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genEPSILON, "EPSILON",	/* F90 */
    FFEINTRIN_specEPSILON,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genEXPONENT, "EXPONENT",	/* F90 */
    FFEINTRIN_specEXPONENT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genFLOOR, "FLOOR",	/* F90 */
    FFEINTRIN_specFLOOR,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genFPABSP, "FPABSP",	/* F2C */
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genFPEXPN, "FPEXPN",	/* F2C */
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genFPFRAC, "FPFRAC",	/* F2C */
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genFPMAKE, "FPMAKE",	/* F2C */
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genFPRRSP, "FPRRSP",	/* F2C */
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genFPSCAL, "FPSCAL",	/* F2C */
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genFRACTION, "FRACTION",	/* F90 */
    FFEINTRIN_specFRACTION,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genHUGE, "HUGE",	/* F90 */
    FFEINTRIN_specHUGE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genIACHAR, "IACHAR",	/* F90, F2C */
    FFEINTRIN_specIACHAR,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genIAND, "IAND",	/* F90, VXT */
    FFEINTRIN_specIAND,
    FFEINTRIN_specIIAND,
    FFEINTRIN_specJIAND,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genIBCLR, "IBCLR",	/* F90, VXT */
    FFEINTRIN_specIBCLR,
    FFEINTRIN_specIIBCLR,
    FFEINTRIN_specJIBCLR,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genIBITS, "IBITS",	/* F90, VXT */
    FFEINTRIN_specIBITS,
    FFEINTRIN_specIIBITS,
    FFEINTRIN_specJIBITS,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genIBSET, "IBSET",	/* F90, VXT */
    FFEINTRIN_specIBSET,
    FFEINTRIN_specIIBSET,
    FFEINTRIN_specJIBSET,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genICHAR, "ICHAR",	/* F90 */
    FFEINTRIN_specICHAR,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genIEOR, "IEOR",	/* F90, VXT */
    FFEINTRIN_specIEOR,
    FFEINTRIN_specIIEOR,
    FFEINTRIN_specJIEOR,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genINDEX, "INDEX",	/* F90 */
    FFEINTRIN_specINDEX,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genIOR, "IOR",	/* F90, VXT */
    FFEINTRIN_specIOR,
    FFEINTRIN_specIIOR,
    FFEINTRIN_specJIOR,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genISHFT, "ISHFT",	/* F90 */
    FFEINTRIN_specISHFT,
    FFEINTRIN_specIISHFT,
    FFEINTRIN_specJISHFT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genISHFTC, "ISHFTC",	/* F90, VXT */
    FFEINTRIN_specISHFTC,
    FFEINTRIN_specIISHFTC,
    FFEINTRIN_specJISHFTC,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genISIGN, "ISIGN",	/* F90 */
    FFEINTRIN_specISIGN,
    FFEINTRIN_specIISIGN,
    FFEINTRIN_specJISIGN,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genKIND, "KIND",	/* F90 */
    FFEINTRIN_specKIND,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genLBOUND, "LBOUND",	/* F90 */
    FFEINTRIN_specLBOUND,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genLEN, "LEN",	/* F90 */
    FFEINTRIN_specLEN,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genLEN_TRIM, "LEN_TRIM",	/* F90 */
    FFEINTRIN_specLEN_TRIM,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genLGE, "LGE",	/* F90 */
    FFEINTRIN_specLGE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genLGT, "LGT",	/* F90 */
    FFEINTRIN_specLGT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genLLE, "LLE",	/* F90 */
    FFEINTRIN_specLLE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genLLT, "LLT",	/* F90 */
    FFEINTRIN_specLLT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genLOGICAL, "LOGICAL",	/* F90 */
    FFEINTRIN_specLOGICAL,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genLSHIFT, "LSHIFT",	/* F2C */
    FFEINTRIN_spec_LSHIFT_I,
    FFEINTRIN_spec_LSHIFT_L,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMATMUL, "MATMUL",	/* F90 */
    FFEINTRIN_specMATMUL,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMAXEXPONENT, "MAXEXPONENT",	/* F90 */
    FFEINTRIN_specMAXEXPONENT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMAXLOC, "MAXLOC",	/* F90 */
    FFEINTRIN_specMAXLOC,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMAXVAL, "MAXVAL",	/* F90 */
    FFEINTRIN_specMAXVAL,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMERGE, "MERGE",	/* F90 */
    FFEINTRIN_specMERGE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMINEXPONENT, "MINEXPONENT",	/* F90 */
    FFEINTRIN_specMINEXPONENT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMINLOC, "MINLOC",	/* F90 */
    FFEINTRIN_specMINLOC,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMINVAL, "MINVAL",	/* F90 */
    FFEINTRIN_specMINVAL,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genMODULO, "MODULO",	/* F90 */
    FFEINTRIN_specMODULO,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genNEAREST, "NEAREST",	/* F90 */
    FFEINTRIN_specNEAREST,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genNOT, "NOT",	/* F2C, F90, VXT */
    FFEINTRIN_specNOT,
    FFEINTRIN_spec_NOT_I,
    FFEINTRIN_spec_NOT_L,
    FFEINTRIN_specINOT,
    FFEINTRIN_specJNOT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genOR, "OR",	/* F2C */
    FFEINTRIN_spec_OR_I,
    FFEINTRIN_spec_OR_L,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genPACK, "PACK",	/* F90 */
    FFEINTRIN_specPACK,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genPRECISION, "PRECISION",	/* F90 */
    FFEINTRIN_specPRECISION,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genPRESENT, "PRESENT",	/* F90 */
    FFEINTRIN_specPRESENT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genPRODUCT, "PRODUCT",	/* F90 */
    FFEINTRIN_specPRODUCT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genQEXT, "QEXT",	/* VXT */
    FFEINTRIN_spec_QEXT_J,
    FFEINTRIN_spec_QEXT_I,
    FFEINTRIN_specQEXT,
    FFEINTRIN_specQEXTD,
    FFEINTRIN_spec_QEXT_Q,
    FFEINTRIN_spec_QEXT_C,
    FFEINTRIN_spec_QEXT_E,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genQFLOAT, "QFLOAT",	/* VXT */
    FFEINTRIN_spec_QFLOAT_J,
    FFEINTRIN_spec_QFLOAT_I,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genRADIX, "RADIX",	/* F90 */
    FFEINTRIN_specRADIX,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genRANGE, "RANGE",	/* F90 */
    FFEINTRIN_specRANGE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genREPEAT, "REPEAT",	/* F90 */
    FFEINTRIN_specREPEAT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genRESHAPE, "RESHAPE",	/* F90 */
    FFEINTRIN_specRESHAPE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genRRSPACING, "RRSPACING",	/* F90 */
    FFEINTRIN_specRRSPACING,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genRSHIFT, "RSHIFT",	/* F2C */
    FFEINTRIN_spec_RSHIFT_I,
    FFEINTRIN_spec_RSHIFT_L,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genSCALE, "SCALE",	/* F90 */
    FFEINTRIN_specSCALE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genSCAN, "SCAN",	/* F90 */
    FFEINTRIN_specSCAN,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genSEL_INT_KIND, "SEL_INT_KIND",	/* F90 */
    FFEINTRIN_specSEL_INT_KIND,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genSEL_REAL_KIND, "SEL_REAL_KIND",	/* F90 */
    FFEINTRIN_specSEL_REAL_KIND,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genSET_EXPONENT, "SET_EXPONENT",	/* F90 */
    FFEINTRIN_specSET_EXPONENT,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genSHAPE, "SHAPE",	/* F90 */
    FFEINTRIN_specSHAPE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genSIND, "SIND",	/* VXT */
    FFEINTRIN_specSIND,
    FFEINTRIN_specDSIND,
    FFEINTRIN_specQSIND,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genSPACING, "SPACING",	/* F90 */
    FFEINTRIN_specSPACING,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genSPREAD, "SPREAD",	/* F90 */
    FFEINTRIN_specSPREAD,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genSUM, "SUM",	/* F90 */
    FFEINTRIN_specSUM,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genTAND, "TAND",	/* VXT */
    FFEINTRIN_specTAND,
    FFEINTRIN_specDTAND,
    FFEINTRIN_specQTAND,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genTINY, "TINY",	/* F90 */
    FFEINTRIN_specTINY,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genTRANSFER, "TRANSFER",	/* F90 */
    FFEINTRIN_specTRANSFER,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genTRANSPOSE, "TRANSPOSE",	/* F90 */
    FFEINTRIN_specTRANSPOSE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genTRIM, "TRIM",	/* F90 */
    FFEINTRIN_specTRIM,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genUBOUND, "UBOUND",	/* F90 */
    FFEINTRIN_specUBOUND,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genUNPACK, "UNPACK",	/* F90 */
    FFEINTRIN_specUNPACK,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genVERIFY, "VERIFY",	/* F90 */
    FFEINTRIN_specVERIFY,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genXOR, "XOR",	/* F2C */
    FFEINTRIN_spec_XOR_I,
    FFEINTRIN_spec_XOR_L,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genZEXT, "ZEXT",	/* VXT */
    FFEINTRIN_spec_JZEXT_N,
    FFEINTRIN_spec_JZEXT_M,
    FFEINTRIN_spec_JZEXT_J,
    FFEINTRIN_spec_IZEXT_N,
    FFEINTRIN_spec_IZEXT_M,
    FFEINTRIN_spec_IZEXT_L,
    FFEINTRIN_spec_IZEXT_J,
    FFEINTRIN_spec_IZEXT_I,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )
DEFGEN (FFEINTRIN_genNONE, "none",
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE,
    FFEINTRIN_specNONE
  )

/* Start off with specific intrinsic implementations in any order
   (currently alpha).  This list corresponds to actual implementations
   of specific intrinsics, so there is no redundancy -- e.g. instead
   of FLOAT and REAL, there is only _REAL_I.  We use this non-
   redundancy when determining which specific intrinsic is meant
   by a generic -- REAL(I) can match either specific REAL or FLOAT,
   but rather than complain about that, we see that the implementations
   are the same.  This approach should allow lots of extensions in
   the form of possibly conflicting intrinsic sets with complaints
   arising only when those sets are enabled and the potentially
   conflicting intrinsics are actually referenced.  */

#define I_ FFEINFO_basictypeINTEGER, FFEINFO_kindtypeINTEGERDEFAULT, NC_
#define L_ FFEINFO_basictypeLOGICAL, FFEINFO_kindtypeLOGICALDEFAULT, NC_
#define R_ FFEINFO_basictypeREAL, FFEINFO_kindtypeREALDEFAULT, NC_
#define D_ FFEINFO_basictypeREAL, FFEINFO_kindtypeREALDOUBLE, NC_
#define C_ FFEINFO_basictypeCOMPLEX, FFEINFO_kindtypeREALDEFAULT, NC_
#define E_ FFEINFO_basictypeCOMPLEX, FFEINFO_kindtypeREALDOUBLE, NC_
#define A_ FFEINFO_basictypeCHARACTER, FFEINFO_kindtypeCHARACTERDEFAULT, 1
#define VOID_ FFEINFO_basictypeNONE, FFEINFO_kindtypeNONE, NC_
#define NC_ FFETARGET_charactersizeNONE
#define cI1_ ffeintrin_check_int_1_
#define cL1_ ffeintrin_check_log_1_
#define cR1_ ffeintrin_check_real_1_
#define cD1_ ffeintrin_check_realdbl_1_
#define cC1_ ffeintrin_check_cmplx_1_
#define cE1_ ffeintrin_check_dcmplx_1_
#define cA1_ ffeintrin_check_char_1_
#define cI1or2_ ffeintrin_check_int_1or2_
#define cL1or2_ ffeintrin_check_log_1or2_
#define cR1or2_ ffeintrin_check_real_1or2_
#define cD1or2_ ffeintrin_check_realdbl_1or2_
#define cC1or2_ ffeintrin_check_cmplx_1or2_
#define cE1or2_ ffeintrin_check_dcmplx_1or2_
#define cI2_ ffeintrin_check_int_2_
#define cL2_ ffeintrin_check_log_2_
#define cR2_ ffeintrin_check_real_2_
#define cD2_ ffeintrin_check_realdbl_2_
#define cA2_ ffeintrin_check_char_2_
#define cI2p_ ffeintrin_check_int_2p_
#define cL2p_ ffeintrin_check_log_2p_
#define cR2p_ ffeintrin_check_real_2p_
#define cD2p_ ffeintrin_check_realdbl_2p_
#define cI2or3_ ffeintrin_check_int_2or3_
#define cL2or3_ ffeintrin_check_log_2or3_
#define cR2or3_ ffeintrin_check_real_2or3_
#define cD2or3_ ffeintrin_check_realdbl_2or3_
#define cC2or3_ ffeintrin_check_cmplx_2or3_
#define cE2or3_ ffeintrin_check_dcmplx_2or3_
#define cI3_ ffeintrin_check_int_3_
#define cL3_ ffeintrin_check_log_3_
#define cR3_ ffeintrin_check_real_3_
#define cD3_ ffeintrin_check_realdbl_3_
#define cA3_ ffeintrin_check_char_3_
#define Void_ ffeintrin_check_void_
DEFIMP (FFEINTRIN_impABS, "ABS", FFECOM_gfrtABS, R_, cR1_)
DEFIMP (FFEINTRIN_impACOS, "ACOS", FFECOM_gfrtACOS, R_, cR1_)
DEFIMP (FFEINTRIN_impAIMAG, "AIMAG", FFECOM_gfrtAIMAG, R_, cC1_)
DEFIMP (FFEINTRIN_impAINT, "AINT", FFECOM_gfrtAINT, R_, cR1_)
DEFIMP (FFEINTRIN_impALOG, "ALOG", FFECOM_gfrtALOG, R_, cR1_)
DEFIMP (FFEINTRIN_impALOG10, "ALOG10", FFECOM_gfrtALOG10, R_, cR1_)
DEFIMP (FFEINTRIN_impAMAX0, "AMAX0", FFECOM_gfrt, R_, cI2p_)
DEFIMP (FFEINTRIN_impAMAX1, "AMAX1", FFECOM_gfrt, R_, cR2p_)
DEFIMP (FFEINTRIN_impAMIN0, "AMIN0", FFECOM_gfrt, R_, cI2p_)
DEFIMP (FFEINTRIN_impAMIN1, "AMIN1", FFECOM_gfrt, R_, cR2p_)
DEFIMP (FFEINTRIN_impAMOD, "AMOD", FFECOM_gfrtAMOD, R_, cR2_)
DEFIMP (FFEINTRIN_impANINT, "ANINT", FFECOM_gfrtANINT, R_, cR1_)
DEFIMP (FFEINTRIN_impASIN, "ASIN", FFECOM_gfrtASIN, R_, cR1_)
DEFIMP (FFEINTRIN_impATAN, "ATAN", FFECOM_gfrtATAN, R_, cR1_)
DEFIMP (FFEINTRIN_impATAN2, "ATAN2", FFECOM_gfrtATAN2, R_, cR2_)
DEFIMP (FFEINTRIN_impCABS, "CABS", FFECOM_gfrtCABS, R_, cC1_)
DEFIMP (FFEINTRIN_impCCOS, "CCOS", FFECOM_gfrtCCOS, C_, cC1_)
DEFIMP (FFEINTRIN_impCEXP, "CEXP", FFECOM_gfrtCEXP, C_, cC1_)
DEFIMP (FFEINTRIN_impCHAR, "CHAR", FFECOM_gfrt, A_, cI1_)
DEFIMP (FFEINTRIN_impCLOG, "CLOG", FFECOM_gfrtCLOG, C_, cC1_)
DEFIMP (FFEINTRIN_impCONJG, "CONJG", FFECOM_gfrtCONJG, C_, cC1_)
DEFIMP (FFEINTRIN_impCOS, "COS", FFECOM_gfrtCOS, R_, cR1_)
DEFIMP (FFEINTRIN_impCOSH, "COSH", FFECOM_gfrtCOSH, R_, cR1_)
DEFIMP (FFEINTRIN_impCSIN, "CSIN", FFECOM_gfrtCSIN, C_, cC1_)
DEFIMP (FFEINTRIN_impCSQRT, "CSQRT", FFECOM_gfrtCSQRT, C_, cC1_)
DEFIMP (FFEINTRIN_impDABS, "DABS", FFECOM_gfrtDABS, D_, cD1_)
DEFIMP (FFEINTRIN_impDACOS, "DACOS", FFECOM_gfrtDACOS, D_, cD1_)
DEFIMP (FFEINTRIN_impDASIN, "DASIN", FFECOM_gfrtDASIN, D_, cD1_)
DEFIMP (FFEINTRIN_impDATAN, "DATAN", FFECOM_gfrtDATAN, D_, cD1_)
DEFIMP (FFEINTRIN_impDATAN2, "DATAN2", FFECOM_gfrtDATAN2, D_, cD2_)
DEFIMP (FFEINTRIN_impDCOS, "DCOS", FFECOM_gfrtDCOS, D_, cD1_)
DEFIMP (FFEINTRIN_impDCOSH, "DCOSH", FFECOM_gfrtDCOSH, D_, cD1_)
DEFIMP (FFEINTRIN_impDDIM, "DDIM", FFECOM_gfrtDDIM, D_, cD2_)
DEFIMP (FFEINTRIN_impDEXP, "DEXP", FFECOM_gfrtDEXP, D_, cD1_)
DEFIMP (FFEINTRIN_impDIM, "DIM", FFECOM_gfrtDIM, R_, cR2_)
DEFIMP (FFEINTRIN_impDINT, "DINT", FFECOM_gfrtDINT, D_, cD1_)
DEFIMP (FFEINTRIN_impDLOG, "DLOG", FFECOM_gfrtDLOG, D_, cD1_)
DEFIMP (FFEINTRIN_impDLOG10, "DLOG10", FFECOM_gfrtDLOG10, D_, cD1_)
DEFIMP (FFEINTRIN_impDMAX1, "DMAX1", FFECOM_gfrt, D_, cD2p_)
DEFIMP (FFEINTRIN_impDMIN1, "DMIN1", FFECOM_gfrt, D_, cD2p_)
DEFIMP (FFEINTRIN_impDMOD, "DMOD", FFECOM_gfrtDMOD, D_, cD2_)
DEFIMP (FFEINTRIN_impDNINT, "DNINT", FFECOM_gfrtDNINT, D_, cD1_)
DEFIMP (FFEINTRIN_impDPROD, "DPROD", FFECOM_gfrtDPROD, D_, cR2_)
DEFIMP (FFEINTRIN_impDSIGN, "DSIGN", FFECOM_gfrtDSIGN, D_, cD2_)
DEFIMP (FFEINTRIN_impDSIN, "DSIN", FFECOM_gfrtDSIN, D_, cD1_)
DEFIMP (FFEINTRIN_impDSINH, "DSINH", FFECOM_gfrtDSINH, D_, cD1_)
DEFIMP (FFEINTRIN_impDSQRT, "DSQRT", FFECOM_gfrtDSQRT, D_, cD1_)
DEFIMP (FFEINTRIN_impDTAN, "DTAN", FFECOM_gfrtDTAN, D_, cD1_)
DEFIMP (FFEINTRIN_impDTANH, "DTANH", FFECOM_gfrtDTANH, D_, cD1_)
DEFIMP (FFEINTRIN_impEXP, "EXP", FFECOM_gfrtEXP, R_, cR1_)
DEFIMP (FFEINTRIN_impIABS, "IABS", FFECOM_gfrtIABS, I_, cI1_)
DEFIMP (FFEINTRIN_impICHAR, "ICHAR", FFECOM_gfrt, I_, cA1_)
DEFIMP (FFEINTRIN_impIDIM, "IDIM", FFECOM_gfrtIDIM, I_, cI2_)
DEFIMP (FFEINTRIN_impIDNINT, "IDNINT", FFECOM_gfrtIDNINT, I_, cD1_)
DEFIMP (FFEINTRIN_impINDEX, "INDEX", FFECOM_gfrtINDEX, I_, cA2_)
DEFIMP (FFEINTRIN_impISIGN, "ISIGN", FFECOM_gfrtISIGN, I_, cI2_)
DEFIMP (FFEINTRIN_impLEN, "LEN", FFECOM_gfrtLEN, I_, cA1_)
DEFIMP (FFEINTRIN_impLGE, "LGE", FFECOM_gfrtLGE, L_, cA2_)
DEFIMP (FFEINTRIN_impLGT, "LGT", FFECOM_gfrtLGT, L_, cA2_)
DEFIMP (FFEINTRIN_impLLE, "LLE", FFECOM_gfrtLLE, L_, cA2_)
DEFIMP (FFEINTRIN_impLLT, "LLT", FFECOM_gfrtLLT, L_, cA2_)
DEFIMP (FFEINTRIN_impMAX0, "MAX0", FFECOM_gfrt, I_, cI2p_)
DEFIMP (FFEINTRIN_impMAX1, "MAX1", FFECOM_gfrt, I_, cR2p_)
DEFIMP (FFEINTRIN_impMIN0, "MIN0", FFECOM_gfrt, I_, cI2p_)
DEFIMP (FFEINTRIN_impMIN1, "MIN1", FFECOM_gfrt, I_, cR2p_)
DEFIMP (FFEINTRIN_impMOD, "MOD", FFECOM_gfrtMOD, I_, cI2_)
DEFIMP (FFEINTRIN_impNINT, "NINT", FFECOM_gfrtNINT, I_, cR1_)
DEFIMP (FFEINTRIN_impSIGN, "SIGN", FFECOM_gfrtSIGN, R_, cR2_)
DEFIMP (FFEINTRIN_impSIN, "SIN", FFECOM_gfrtSIN, R_, cR1_)
DEFIMP (FFEINTRIN_impSINH, "SINH", FFECOM_gfrtSINH, R_, cR1_)
DEFIMP (FFEINTRIN_impSQRT, "SQRT", FFECOM_gfrtSQRT, R_, cR1_)
DEFIMP (FFEINTRIN_impTAN, "TAN", FFECOM_gfrtTAN, R_, cR1_)
DEFIMP (FFEINTRIN_impTANH, "TANH", FFECOM_gfrtTANH, R_, cR1_)
DEFIMP (FFEINTRIN_imp_CMPLX_C, "cmplx_c", FFECOM_gfrt, C_, cC1or2_)
DEFIMP (FFEINTRIN_imp_CMPLX_D, "cmplx_d", FFECOM_gfrt, C_, cD1or2_)
DEFIMP (FFEINTRIN_imp_CMPLX_I, "cmplx_i", FFECOM_gfrt, C_, cI1or2_)
DEFIMP (FFEINTRIN_imp_CMPLX_R, "cmplx_r", FFECOM_gfrt, C_, cR1or2_)
DEFIMP (FFEINTRIN_imp_DBLE_C, "dble_c", FFECOM_gfrt, D_, cC1_)
DEFIMP (FFEINTRIN_imp_DBLE_D, "dble_d", FFECOM_gfrt, D_, cD1_)
DEFIMP (FFEINTRIN_imp_DBLE_I, "dble_i", FFECOM_gfrt, D_, cI1_)
DEFIMP (FFEINTRIN_imp_DBLE_R, "dble_r", FFECOM_gfrt, D_, cR1_)
DEFIMP (FFEINTRIN_imp_INT_C, "int_c", FFECOM_gfrt, I_, cC1_)
DEFIMP (FFEINTRIN_imp_INT_D, "int_d", FFECOM_gfrt, I_, cD1_)
DEFIMP (FFEINTRIN_imp_INT_I, "int_i", FFECOM_gfrt, I_, cI1_)
DEFIMP (FFEINTRIN_imp_INT_R, "int_r", FFECOM_gfrt, I_, cR1_)
DEFIMP (FFEINTRIN_imp_REAL_C, "real_c", FFECOM_gfrt, R_, cC1_)
DEFIMP (FFEINTRIN_imp_REAL_D, "real_d", FFECOM_gfrt, R_, cD1_)
DEFIMP (FFEINTRIN_imp_REAL_I, "real_i", FFECOM_gfrt, R_, cI1_)
DEFIMP (FFEINTRIN_imp_REAL_R, "real_r", FFECOM_gfrt, R_, cR1_)
DEFIMP (FFEINTRIN_impACHAR, "ACHAR", FFECOM_gfrt, A_, cI1_)
DEFIMP (FFEINTRIN_impBIT_SIZE, "BIT_SIZE", FFECOM_gfrt, I_, cI1_)
DEFIMP (FFEINTRIN_impBTEST, "BTEST", FFECOM_gfrt, L_, cI2_)
DEFIMP (FFEINTRIN_impCDABS, "CDABS", FFECOM_gfrtCDABS, D_, cE1_)
DEFIMP (FFEINTRIN_impCDCOS, "CDCOS", FFECOM_gfrtCDCOS, E_, cE1_)
DEFIMP (FFEINTRIN_impCDEXP, "CDEXP", FFECOM_gfrtCDEXP, E_, cE1_)
DEFIMP (FFEINTRIN_impCDLOG, "CDLOG", FFECOM_gfrtCDLOG, E_, cE1_)
DEFIMP (FFEINTRIN_impCDSIN, "CDSIN", FFECOM_gfrtCDSIN, E_, cE1_)
DEFIMP (FFEINTRIN_impCDSQRT, "CDSQRT", FFECOM_gfrtCDSQRT, E_, cE1_)
DEFIMP (FFEINTRIN_impDCONJG, "DCONJG", FFECOM_gfrtDCONJG, E_, cE1_)
DEFIMP (FFEINTRIN_impDIMAG, "DIMAG", FFECOM_gfrtDIMAG, D_, cE1_)
DEFIMP (FFEINTRIN_impIACHAR, "IACHAR", FFECOM_gfrt, I_, cA1_)
DEFIMP (FFEINTRIN_impIAND, "IAND", FFECOM_gfrt, I_, cI2_)
DEFIMP (FFEINTRIN_impIBCLR, "IBCLR", FFECOM_gfrt, I_, cI2_)
DEFIMP (FFEINTRIN_impIBITS, "IBITS", FFECOM_gfrt, I_, cI3_)
DEFIMP (FFEINTRIN_impIBSET, "IBSET", FFECOM_gfrt, I_, cI2_)
DEFIMP (FFEINTRIN_impIEOR, "IEOR", FFECOM_gfrt, I_, cI2_)
DEFIMP (FFEINTRIN_impIOR, "IOR", FFECOM_gfrt, I_, cI2_)
DEFIMP (FFEINTRIN_impISHFT, "ISHFT", FFECOM_gfrt, I_, cI2_)
DEFIMP (FFEINTRIN_impISHFTC, "ISHFTC", FFECOM_gfrt, I_, cI3_)
DEFIMP (FFEINTRIN_impLOC, "LOC", FFECOM_gfrt, I_, ffeintrin_check_loc_)
DEFIMP (FFEINTRIN_impMVBITS, "MVBITS", FFECOM_gfrt, VOID_, ffeintrin_check_mvbits_)
DEFIMP (FFEINTRIN_impNOT, "NOT", FFECOM_gfrt, I_, cI1_)
DEFIMP (FFEINTRIN_imp_AND_L, "and_l", FFECOM_gfrt, L_, cL2_)
DEFIMP (FFEINTRIN_imp_CMPLX_E, "cmplx_e", FFECOM_gfrt, C_, cE1or2_)
DEFIMP (FFEINTRIN_imp_DBLE_E, "dble_e", FFECOM_gfrt, D_, cE1_)
DEFIMP (FFEINTRIN_imp_DCMPLX_C, "dcmplx_c", FFECOM_gfrt, E_, cC1or2_)
DEFIMP (FFEINTRIN_imp_DCMPLX_D, "dcmplx_d", FFECOM_gfrt, E_, cD1or2_)
DEFIMP (FFEINTRIN_imp_DCMPLX_E, "dcmplx_e", FFECOM_gfrt, E_, cE1or2_)
DEFIMP (FFEINTRIN_imp_DCMPLX_I, "dcmplx_i", FFECOM_gfrt, E_, cI1or2_)
DEFIMP (FFEINTRIN_imp_DCMPLX_R, "dcmplx_r", FFECOM_gfrt, E_, cR1or2_)
DEFIMP (FFEINTRIN_imp_INT_E, "int_e", FFECOM_gfrt, I_, cE1_)
DEFIMP (FFEINTRIN_imp_LSHIFT_I, "lshift_i", FFECOM_gfrt, I_, cI2_)
DEFIMP (FFEINTRIN_imp_LSHIFT_L, "lshift_l", FFECOM_gfrt, L_, cL2_)
DEFIMP (FFEINTRIN_imp_NOT_L, "not_l", FFECOM_gfrt, L_, cL1_)
DEFIMP (FFEINTRIN_imp_OR_L, "or_l", FFECOM_gfrt, L_, cL2_)
DEFIMP (FFEINTRIN_imp_REAL_E, "real_e", FFECOM_gfrt, R_, cE1_)
DEFIMP (FFEINTRIN_imp_RSHIFT_I, "rshift_i", FFECOM_gfrt, I_, cI2_)
DEFIMP (FFEINTRIN_imp_RSHIFT_L, "rshift_l", FFECOM_gfrt, L_, cL2_)
DEFIMP (FFEINTRIN_imp_XOR_L, "xor_l", FFECOM_gfrt, L_, cL2_)
DEFIMP (FFEINTRIN_impNONE, "none", FFECOM_gfrt, VOID_, Void_)
#undef I_
#undef L_
#undef R_
#undef D_
#undef C_
#undef A_
#undef NC_
#undef cI1_
#undef cR1_
#undef cD1_
#undef cC1_
#undef cA1_
#undef cI1or2_
#undef cR1or2_
#undef cD1or2_
#undef cC1or2_


/* Start off with named specific intrinsics in any order (currently
   alpha).  This list corresponds to both named intrinsics in the
   source code (as in "INTRINSIC FOO", "CALL X(FOO)", and "FOO(...)")
   and named/unnamed intrinsics accessed via generic intrinsics
   (as in "INT((1.,2.))", which corresponds to an unnamed specific
   intrinsic that converts a COMPLEX to an INTEGER).  There is
   redundancy of implementation in this list, as in FLOAT and REAL
   meaning the same thing (convert INTEGER to REAL).  */

DEFSPEC (FFEINTRIN_specABS,
    "ABS",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impABS
  )
DEFSPEC (FFEINTRIN_specACOS,
    "ACOS",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impACOS
  )
DEFSPEC (FFEINTRIN_specAIMAG,
    "AIMAG",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impAIMAG
  )
DEFSPEC (FFEINTRIN_specAINT,
    "AINT",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impAINT
  )
DEFSPEC (FFEINTRIN_specALOG,
    "ALOG",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impALOG
  )
DEFSPEC (FFEINTRIN_specALOG10,
    "ALOG10",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impALOG10
  )
DEFSPEC (FFEINTRIN_specAMAX0,
    "AMAX0",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impAMAX0
  )
DEFSPEC (FFEINTRIN_specAMAX1,
    "AMAX1",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impAMAX1
  )
DEFSPEC (FFEINTRIN_specAMIN0,
    "AMIN0",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impAMIN0
  )
DEFSPEC (FFEINTRIN_specAMIN1,
    "AMIN1",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impAMIN1
  )
DEFSPEC (FFEINTRIN_specAMOD,
    "AMOD",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impAMOD
  )
DEFSPEC (FFEINTRIN_specANINT,
    "ANINT",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impANINT
  )
DEFSPEC (FFEINTRIN_specASIN,
    "ASIN",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impASIN
  )
DEFSPEC (FFEINTRIN_specATAN,
    "ATAN",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impATAN
  )
DEFSPEC (FFEINTRIN_specATAN2,
    "ATAN2",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impATAN2
  )
DEFSPEC (FFEINTRIN_specCABS,
    "CABS",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impCABS
  )
DEFSPEC (FFEINTRIN_specCCOS,
    "CCOS",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impCCOS
  )
DEFSPEC (FFEINTRIN_specCEXP,
    "CEXP",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impCEXP
  )
DEFSPEC (FFEINTRIN_specCHAR,
    "CHAR",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impCHAR
  )
DEFSPEC (FFEINTRIN_specCLOG,
    "CLOG",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impCLOG
  )
DEFSPEC (FFEINTRIN_specCONJG,
    "CONJG",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impCONJG
  )
DEFSPEC (FFEINTRIN_specCOS,
    "COS",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impCOS
  )
DEFSPEC (FFEINTRIN_specCOSH,
    "COSH",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impCOSH
  )
DEFSPEC (FFEINTRIN_specCSIN,
    "CSIN",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impCSIN
  )
DEFSPEC (FFEINTRIN_specCSQRT,
    "CSQRT",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impCSQRT
  )
DEFSPEC (FFEINTRIN_specDABS,
    "DABS",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDABS
  )
DEFSPEC (FFEINTRIN_specDACOS,
    "DACOS",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDACOS
  )
DEFSPEC (FFEINTRIN_specDASIN,
    "DASIN",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDASIN
  )
DEFSPEC (FFEINTRIN_specDATAN,
    "DATAN",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDATAN
  )
DEFSPEC (FFEINTRIN_specDATAN2,
    "DATAN2",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDATAN2
  )
DEFSPEC (FFEINTRIN_specDCOS,
    "DCOS",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDCOS
  )
DEFSPEC (FFEINTRIN_specDCOSH,
    "DCOSH",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDCOSH
  )
DEFSPEC (FFEINTRIN_specDDIM,
    "DDIM",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDDIM
  )
DEFSPEC (FFEINTRIN_specDEXP,
    "DEXP",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDEXP
  )
DEFSPEC (FFEINTRIN_specDIM,
    "DIM",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDIM
  )
DEFSPEC (FFEINTRIN_specDINT,
    "DINT",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDINT
  )
DEFSPEC (FFEINTRIN_specDLOG,
    "DLOG",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDLOG
  )
DEFSPEC (FFEINTRIN_specDLOG10,
    "DLOG10",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDLOG10
  )
DEFSPEC (FFEINTRIN_specDMAX1,
    "DMAX1",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDMAX1
  )
DEFSPEC (FFEINTRIN_specDMIN1,
    "DMIN1",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDMIN1
  )
DEFSPEC (FFEINTRIN_specDMOD,
    "DMOD",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDMOD
  )
DEFSPEC (FFEINTRIN_specDNINT,
    "DNINT",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDNINT
  )
DEFSPEC (FFEINTRIN_specDPROD,
    "DPROD",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDPROD
  )
DEFSPEC (FFEINTRIN_specDSIGN,
    "DSIGN",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDSIGN
  )
DEFSPEC (FFEINTRIN_specDSIN,
    "DSIN",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDSIN
  )
DEFSPEC (FFEINTRIN_specDSINH,
    "DSINH",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDSINH
  )
DEFSPEC (FFEINTRIN_specDSQRT,
    "DSQRT",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDSQRT
  )
DEFSPEC (FFEINTRIN_specDTAN,
    "DTAN",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDTAN
  )
DEFSPEC (FFEINTRIN_specDTANH,
    "DTANH",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impDTANH
  )
DEFSPEC (FFEINTRIN_specEXP,
    "EXP",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impEXP
  )
DEFSPEC (FFEINTRIN_specFLOAT,
    "FLOAT",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_REAL_I
  )
DEFSPEC (FFEINTRIN_specIABS,
    "IABS",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impIABS
  )
DEFSPEC (FFEINTRIN_specICHAR,
    "ICHAR",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impICHAR
  )
DEFSPEC (FFEINTRIN_specIDIM,
    "IDIM",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impIDIM
  )
DEFSPEC (FFEINTRIN_specIDINT,
    "IDINT",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_INT_D
  )
DEFSPEC (FFEINTRIN_specIDNINT,
    "IDNINT",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impIDNINT
  )
DEFSPEC (FFEINTRIN_specIFIX,
    "IFIX",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_INT_R
  )
DEFSPEC (FFEINTRIN_specINDEX,
    "INDEX",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impINDEX
  )
DEFSPEC (FFEINTRIN_specINT,
    "INT",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_INT_R
  )
DEFSPEC (FFEINTRIN_specISIGN,
    "ISIGN",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impISIGN
  )
DEFSPEC (FFEINTRIN_specLEN,
    "LEN",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impLEN
  )
DEFSPEC (FFEINTRIN_specLGE,
    "LGE",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impLGE
  )
DEFSPEC (FFEINTRIN_specLGT,
    "LGT",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impLGT
  )
DEFSPEC (FFEINTRIN_specLLE,
    "LLE",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impLLE
  )
DEFSPEC (FFEINTRIN_specLLT,
    "LLT",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impLLT
  )
DEFSPEC (FFEINTRIN_specMAX0,
    "MAX0",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impMAX0
  )
DEFSPEC (FFEINTRIN_specMAX1,
    "MAX1",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impMAX1
  )
DEFSPEC (FFEINTRIN_specMIN0,
    "MIN0",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impMIN0
  )
DEFSPEC (FFEINTRIN_specMIN1,
    "MIN1",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impMIN1
  )
DEFSPEC (FFEINTRIN_specMOD,
    "MOD",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impMOD
  )
DEFSPEC (FFEINTRIN_specNINT,
    "NINT",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impNINT
  )
DEFSPEC (FFEINTRIN_specREAL,
    "REAL",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_REAL_I
  )
DEFSPEC (FFEINTRIN_specSIGN,
    "SIGN",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impSIGN
  )
DEFSPEC (FFEINTRIN_specSIN,
    "SIN",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impSIN
  )
DEFSPEC (FFEINTRIN_specSINH,
    "SINH",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impSINH
  )
DEFSPEC (FFEINTRIN_specSNGL,
    "SNGL",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_REAL_D
  )
DEFSPEC (FFEINTRIN_specSQRT,
    "SQRT",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impSQRT
  )
DEFSPEC (FFEINTRIN_specTAN,
    "TAN",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impTAN
  )
DEFSPEC (FFEINTRIN_specTANH,
    "TANH",
    TRUE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impTANH
  )
DEFSPEC (FFEINTRIN_spec_CMPLX_C,
    "cmplx_c",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_CMPLX_C
  )
DEFSPEC (FFEINTRIN_spec_CMPLX_D,
    "cmplx_d",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_CMPLX_D
  )
DEFSPEC (FFEINTRIN_spec_CMPLX_I,
    "cmplx_i",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_CMPLX_I
  )
DEFSPEC (FFEINTRIN_spec_CMPLX_R,
    "cmplx_r",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_CMPLX_R
  )
DEFSPEC (FFEINTRIN_spec_DBLE_C,
    "dble_c",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_DBLE_C
  )
DEFSPEC (FFEINTRIN_spec_DBLE_D,
    "dble_d",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_DBLE_D
  )
DEFSPEC (FFEINTRIN_spec_DBLE_I,
    "dble_i",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_DBLE_I
  )
DEFSPEC (FFEINTRIN_spec_DBLE_J,
    "dble_j",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_DBLE_R,
    "dble_r",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_DBLE_R
  )
DEFSPEC (FFEINTRIN_spec_INT_C,
    "int_c",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_INT_C
  )
DEFSPEC (FFEINTRIN_spec_INT_I,
    "int_i",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_INT_I
  )
DEFSPEC (FFEINTRIN_spec_REAL_C,
    "real_c",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_REAL_C
  )
DEFSPEC (FFEINTRIN_spec_REAL_R,
    "real_r",
    FALSE,
    FFEINTRIN_familyF77,
    FFEINTRIN_imp_REAL_R
  )
DEFSPEC (FFEINTRIN_specACHAR,
    "ACHAR",
    FALSE,
    FFEINTRIN_familyASC,
    FFEINTRIN_impACHAR
  )
DEFSPEC (FFEINTRIN_specACOSD,
    "ACOSD",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specADJUSTL,
    "ADJUSTL",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specADJUSTR,
    "ADJUSTR",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specAIMAX0,
    "AIMAX0",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specAIMIN0,
    "AIMIN0",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specAJMAX0,
    "AJMAX0",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impAMAX0
  )
DEFSPEC (FFEINTRIN_specAJMIN0,
    "AJMIN0",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impAMIN0
  )
DEFSPEC (FFEINTRIN_specALL,
    "ALL",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specALLOCATED,
    "ALLOCATED",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specANY,
    "ANY",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specASIND,
    "ASIND",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specASSOCIATED,
    "ASSOCIATED",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specATAN2D,
    "ATAN2D",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specATAND,
    "ATAND",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specBIT_SIZE,
    "BIT_SIZE",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impBIT_SIZE
  )
DEFSPEC (FFEINTRIN_specBITEST,
    "BITEST",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specBJTEST,
    "BJTEST",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impBTEST
  )
DEFSPEC (FFEINTRIN_specBTEST,
    "BTEST",
    FALSE,
    FFEINTRIN_familyMIL,
    FFEINTRIN_impBTEST
  )
DEFSPEC (FFEINTRIN_specCDABS,
    "CDABS",
    TRUE,
    FFEINTRIN_familyFVZ,
    FFEINTRIN_impCDABS
  )
DEFSPEC (FFEINTRIN_specCDCOS,
    "CDCOS",
    TRUE,
    FFEINTRIN_familyFVZ,
    FFEINTRIN_impCDCOS
  )
DEFSPEC (FFEINTRIN_specCDEXP,
    "CDEXP",
    TRUE,
    FFEINTRIN_familyFVZ,
    FFEINTRIN_impCDEXP
  )
DEFSPEC (FFEINTRIN_specCDLOG,
    "CDLOG",
    TRUE,
    FFEINTRIN_familyFVZ,
    FFEINTRIN_impCDLOG
  )
DEFSPEC (FFEINTRIN_specCDSIN,
    "CDSIN",
    TRUE,
    FFEINTRIN_familyFVZ,
    FFEINTRIN_impCDSIN
  )
DEFSPEC (FFEINTRIN_specCDSQRT,
    "CDSQRT",
    TRUE,
    FFEINTRIN_familyFVZ,
    FFEINTRIN_impCDSQRT
  )
DEFSPEC (FFEINTRIN_specCEILING,
    "CEILING",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specCOSD,
    "COSD",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specCOUNT,
    "COUNT",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specCSHIFT,
    "CSHIFT",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specDACOSD,
    "DACOSD",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specDASIND,
    "DASIND",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specDATAN2D,
    "DATAN2D",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specDATAND,
    "DATAND",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specDATE_AND_TIME,
    "DATE_AND_TIME",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specDBLE,
    "DBLE",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_imp_DBLE_R
  )
DEFSPEC (FFEINTRIN_specDBLEQ,
    "DBLEQ",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specDCONJG,
    "DCONJG",
    TRUE,
    FFEINTRIN_familyFVZ,
    FFEINTRIN_impDCONJG
  )
DEFSPEC (FFEINTRIN_specDCOSD,
    "DCOSD",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specDFLOTI,
    "DFLOTI",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specDFLOTJ,
    "DFLOTJ",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_imp_DBLE_I
  )
DEFSPEC (FFEINTRIN_specDIGITS,
    "DIGITS",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specDIMAG,
    "DIMAG",
    TRUE,
    FFEINTRIN_familyFVZ,
    FFEINTRIN_impDIMAG
  )
DEFSPEC (FFEINTRIN_specDOT_PRODUCT,
    "DOT_PRODUCT",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specDREAL,
    "DREAL",
    FALSE,
    FFEINTRIN_familyFVZ,
    FFEINTRIN_imp_DBLE_E
  )
DEFSPEC (FFEINTRIN_specDSIND,
    "DSIND",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specDTAND,
    "DTAND",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specEOSHIFT,
    "EOSHIFT",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specEPSILON,
    "EPSILON",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specEXPONENT,
    "EXPONENT",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specFLOATI,
    "FLOATI",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specFLOATJ,
    "FLOATJ",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_imp_REAL_I
  )
DEFSPEC (FFEINTRIN_specFLOOR,
    "FLOOR",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specFRACTION,
    "FRACTION",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specHUGE,
    "HUGE",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIACHAR,
    "IACHAR",
    FALSE,
    FFEINTRIN_familyASC,
    FFEINTRIN_impIACHAR
  )
DEFSPEC (FFEINTRIN_specIAND,
    "IAND",
    FALSE,
    FFEINTRIN_familyMIL,
    FFEINTRIN_impIAND
  )
DEFSPEC (FFEINTRIN_specIBCLR,
    "IBCLR",
    FALSE,
    FFEINTRIN_familyMIL,
    FFEINTRIN_impIBCLR
  )
DEFSPEC (FFEINTRIN_specIBITS,
    "IBITS",
    FALSE,
    FFEINTRIN_familyMIL,
    FFEINTRIN_impIBITS
  )
DEFSPEC (FFEINTRIN_specIBSET,
    "IBSET",
    FALSE,
    FFEINTRIN_familyMIL,
    FFEINTRIN_impIBSET
  )
DEFSPEC (FFEINTRIN_specIEOR,
    "IEOR",
    FALSE,
    FFEINTRIN_familyMIL,
    FFEINTRIN_impIEOR
  )
DEFSPEC (FFEINTRIN_specIIABS,
    "IIABS",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIIAND,
    "IIAND",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIIBCLR,
    "IIBCLR",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIIBITS,
    "IIBITS",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIIBSET,
    "IIBSET",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIIDIM,
    "IIDIM",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIIDINT,
    "IIDINT",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIIDNNT,
    "IIDNNT",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIIEOR,
    "IIEOR",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIIFIX,
    "IIFIX",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIINT,
    "IINT",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIIOR,
    "IIOR",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIIQINT,
    "IIQINT",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIIQNNT,
    "IIQNNT",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIISHFT,
    "IISHFT",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIISHFTC,
    "IISHFTC",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIISIGN,
    "IISIGN",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIMAX0,
    "IMAX0",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIMAX1,
    "IMAX1",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIMIN0,
    "IMIN0",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIMIN1,
    "IMIN1",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIMOD,
    "IMOD",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specININT,
    "ININT",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specINOT,
    "INOT",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specIOR,
    "IOR",
    FALSE,
    FFEINTRIN_familyMIL,
    FFEINTRIN_impIOR
  )
DEFSPEC (FFEINTRIN_specISHFT,
    "ISHFT",
    FALSE,
    FFEINTRIN_familyMIL,
    FFEINTRIN_impISHFT
  )
DEFSPEC (FFEINTRIN_specISHFTC,
    "ISHFTC",
    FALSE,
    FFEINTRIN_familyMIL,
    FFEINTRIN_impISHFTC
  )
DEFSPEC (FFEINTRIN_specIZEXT,
    "IZEXT",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specJIABS,
    "JIABS",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impIABS
  )
DEFSPEC (FFEINTRIN_specJIAND,
    "JIAND",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impIAND
  )
DEFSPEC (FFEINTRIN_specJIBCLR,
    "JIBCLR",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impIBCLR
  )
DEFSPEC (FFEINTRIN_specJIBITS,
    "JIBITS",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impIBITS
  )
DEFSPEC (FFEINTRIN_specJIBSET,
    "JIBSET",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impIBSET
  )
DEFSPEC (FFEINTRIN_specJIDIM,
    "JIDIM",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impIDIM
  )
DEFSPEC (FFEINTRIN_specJIDINT,
    "JIDINT",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_imp_INT_D
  )
DEFSPEC (FFEINTRIN_specJIDNNT,
    "JIDNNT",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impIDNINT
  )
DEFSPEC (FFEINTRIN_specJIEOR,
    "JIEOR",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impIEOR
  )
DEFSPEC (FFEINTRIN_specJIFIX,
    "JIFIX",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_imp_INT_R
  )
DEFSPEC (FFEINTRIN_specJINT,
    "JINT",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_imp_INT_R
  )
DEFSPEC (FFEINTRIN_specJIOR,
    "JIOR",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impIOR
  )
DEFSPEC (FFEINTRIN_specJIQINT,
    "JIQINT",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specJIQNNT,
    "JIQNNT",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specJISHFT,
    "JISHFT",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impISHFT
  )
DEFSPEC (FFEINTRIN_specJISHFTC,
    "JISHFTC",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impISHFTC
  )
DEFSPEC (FFEINTRIN_specJISIGN,
    "JISIGN",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impISIGN
  )
DEFSPEC (FFEINTRIN_specJMAX0,
    "JMAX0",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impMAX0
  )
DEFSPEC (FFEINTRIN_specJMAX1,
    "JMAX1",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impMAX1
  )
DEFSPEC (FFEINTRIN_specJMIN0,
    "JMIN0",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impMIN0
  )
DEFSPEC (FFEINTRIN_specJMIN1,
    "JMIN1",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impMIN1
  )
DEFSPEC (FFEINTRIN_specJMOD,
    "JMOD",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impMOD
  )
DEFSPEC (FFEINTRIN_specJNINT,
    "JNINT",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNINT
  )
DEFSPEC (FFEINTRIN_specJNOT,
    "JNOT",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNOT
  )
DEFSPEC (FFEINTRIN_specJZEXT,
    "JZEXT",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specKIND,
    "KIND",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specLBOUND,
    "LBOUND",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specLEN_TRIM,
    "LEN_TRIM",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specLOC,
    "LOC",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impLOC
  )
DEFSPEC (FFEINTRIN_specLOGICAL,
    "LOGICAL",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specMATMUL,
    "MATMUL",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specMAXEXPONENT,
    "MAXEXPONENT",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specMAXLOC,
    "MAXLOC",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specMAXVAL,
    "MAXVAL",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specMERGE,
    "MERGE",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specMINEXPONENT,
    "MINEXPONENT",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specMINLOC,
    "MINLOC",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specMINVAL,
    "MINVAL",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specMODULO,
    "MODULO",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specMVBITS,
    "MVBITS",
    FALSE,
    FFEINTRIN_familyMIL,
    FFEINTRIN_impMVBITS
  )
DEFSPEC (FFEINTRIN_specNEAREST,
    "NEAREST",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specNOT,
    "NOT",
    FALSE,
    FFEINTRIN_familyMIL,
    FFEINTRIN_impNOT
  )
DEFSPEC (FFEINTRIN_specPACK,
    "PACK",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specPRECISION,
    "PRECISION",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specPRESENT,
    "PRESENT",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specPRODUCT,
    "PRODUCT",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQABS,
    "QABS",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQACOS,
    "QACOS",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQACOSD,
    "QACOSD",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQASIN,
    "QASIN",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQASIND,
    "QASIND",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQATAN,
    "QATAN",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQATAN2,
    "QATAN2",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQATAN2D,
    "QATAN2D",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQATAND,
    "QATAND",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQCOS,
    "QCOS",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQCOSD,
    "QCOSD",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQCOSH,
    "QCOSH",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQDIM,
    "QDIM",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQEXP,
    "QEXP",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQEXT,
    "QEXT",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQEXTD,
    "QEXTD",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQINT,
    "QINT",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQLOG,
    "QLOG",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQLOG10,
    "QLOG10",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQMAX1,
    "QMAX1",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQMIN1,
    "QMIN1",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQMOD,
    "QMOD",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQNINT,
    "QNINT",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQSIGN,
    "QSIGN",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQSIN,
    "QSIN",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQSIND,
    "QSIND",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQSINH,
    "QSINH",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQSQRT,
    "QSQRT",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQTAN,
    "QTAN",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQTAND,
    "QTAND",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specQTANH,
    "QTANH",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specRADIX,
    "RADIX",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specRANDOM_NUMBER,
    "RANDOM_NUMBER",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specRANDOM_SEED,
    "RANDOM_SEED",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specRANGE,
    "RANGE",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specREPEAT,
    "REPEAT",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specRESHAPE,
    "RESHAPE",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specRRSPACING,
    "RRSPACING",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specSCALE,
    "SCALE",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specSCAN,
    "SCAN",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specSEL_INT_KIND,
    "SEL_INT_KIND",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specSEL_REAL_KIND,
    "SEL_REAL_KIND",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specSET_EXPONENT,
    "SET_EXPONENT",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specSHAPE,
    "SHAPE",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specSIND,
    "SIND",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specSNGLQ,
    "SNGLQ",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specSPACING,
    "SPACING",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specSPREAD,
    "SPREAD",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specSUM,
    "SUM",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specSYSTEM_CLOCK,
    "SYSTEM_CLOCK",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specTAND,
    "TAND",
    TRUE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specTINY,
    "TINY",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specTRANSFER,
    "TRANSFER",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specTRANSPOSE,
    "TRANSPOSE",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specTRIM,
    "TRIM",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specUBOUND,
    "UBOUND",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specUNPACK,
    "UNPACK",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specVERIFY,
    "VERIFY",
    FALSE,
    FFEINTRIN_familyF90,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specZABS,
    "ZABS",
    TRUE,
    FFEINTRIN_familyF2Z,
    FFEINTRIN_impCDABS
  )
DEFSPEC (FFEINTRIN_specZCOS,
    "ZCOS",
    TRUE,
    FFEINTRIN_familyF2Z,
    FFEINTRIN_impCDCOS
  )
DEFSPEC (FFEINTRIN_specZEXP,
    "ZEXP",
    TRUE,
    FFEINTRIN_familyF2Z,
    FFEINTRIN_impCDEXP
  )
DEFSPEC (FFEINTRIN_specZEXT,
    "ZEXT",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_specZLOG,
    "ZLOG",
    TRUE,
    FFEINTRIN_familyF2Z,
    FFEINTRIN_impCDLOG
  )
DEFSPEC (FFEINTRIN_specZSIN,
    "ZSIN",
    TRUE,
    FFEINTRIN_familyF2Z,
    FFEINTRIN_impCDSIN
  )
DEFSPEC (FFEINTRIN_specZSQRT,
    "ZSQRT",
    TRUE,
    FFEINTRIN_familyF2Z,
    FFEINTRIN_impCDSQRT
  )
DEFSPEC (FFEINTRIN_spec_AND_I,
    "and_i",
    FALSE,
    FFEINTRIN_familyF2C,
    FFEINTRIN_impIAND
  )
DEFSPEC (FFEINTRIN_spec_AND_L,
    "and_l",
    FALSE,
    FFEINTRIN_familyF2C,
    FFEINTRIN_imp_AND_L
  )
DEFSPEC (FFEINTRIN_spec_CHAR_J,
    "char_j",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_CHAR_N,
    "char_n",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_CMPLX_E,
    "cmplx_e",
    FALSE,
    FFEINTRIN_familyFVZ,
    FFEINTRIN_imp_CMPLX_E
  )
DEFSPEC (FFEINTRIN_spec_CMPLX_J,
    "cmplx_j",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_CMPLX_Q,
    "cmplx_q",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_DBLE_E,
    "dble_e",
    FALSE,
    FFEINTRIN_familyDCP,
    FFEINTRIN_imp_DBLE_E
  )
DEFSPEC (FFEINTRIN_spec_DCMPLX_C,
    "dcmplx_c",
    FALSE,
    FFEINTRIN_familyDCP,
    FFEINTRIN_imp_DCMPLX_C
  )
DEFSPEC (FFEINTRIN_spec_DCMPLX_D,
    "dcmplx_d",
    FALSE,
    FFEINTRIN_familyDCP,
    FFEINTRIN_imp_DCMPLX_D
  )
DEFSPEC (FFEINTRIN_spec_DCMPLX_E,
    "dcmplx_e",
    FALSE,
    FFEINTRIN_familyFVZ,
    FFEINTRIN_imp_DCMPLX_E
  )
DEFSPEC (FFEINTRIN_spec_DCMPLX_I,
    "dcmplx_i",
    FALSE,
    FFEINTRIN_familyDCP,
    FFEINTRIN_imp_DCMPLX_I
  )
DEFSPEC (FFEINTRIN_spec_DCMPLX_J,
    "dcmplx_j",
    FALSE,
    FFEINTRIN_familyDCP,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_DCMPLX_Q,
    "dcmplx_q",
    FALSE,
    FFEINTRIN_familyDCP,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_DCMPLX_R,
    "dcmplx_r",
    FALSE,
    FFEINTRIN_familyDCP,
    FFEINTRIN_imp_DCMPLX_R
  )
DEFSPEC (FFEINTRIN_spec_IINT_C,
    "iint_c",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_imp_INT_C
  )
DEFSPEC (FFEINTRIN_spec_IINT_E,
    "iint_e",
    FALSE,
    FFEINTRIN_familyFVZ,
    FFEINTRIN_imp_INT_E
  )
DEFSPEC (FFEINTRIN_spec_IMAG_E,
    "imag_e",
    TRUE,
    FFEINTRIN_familyDCP,
    FFEINTRIN_impDIMAG
  )
DEFSPEC (FFEINTRIN_spec_IZEXT_N,
    "izext_n",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_IZEXT_M,
    "izext_m",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_IZEXT_L,
    "izext_l",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_IZEXT_J,
    "izext_j",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_IZEXT_I,
    "izext_i",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_JINT_C,
    "jint_c",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_JINT_E,
    "jint_e",
    FALSE,
    FFEINTRIN_familyFVZ,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_JZEXT_N,
    "jzext_n",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_JZEXT_M,
    "jzext_m",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_JZEXT_J,
    "jzext_j",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_LSHIFT_I,
    "lshift_i",
    FALSE,
    FFEINTRIN_familyF2C,
    FFEINTRIN_imp_LSHIFT_I
  )
DEFSPEC (FFEINTRIN_spec_LSHIFT_L,
    "lshift_l",
    FALSE,
    FFEINTRIN_familyF2C,
    FFEINTRIN_imp_LSHIFT_L
  )
DEFSPEC (FFEINTRIN_spec_NOT_I,
    "not_i",
    FALSE,
    FFEINTRIN_familyF2C,
    FFEINTRIN_impNOT
  )
DEFSPEC (FFEINTRIN_spec_NOT_L,
    "not_l",
    FALSE,
    FFEINTRIN_familyF2C,
    FFEINTRIN_imp_NOT_L
  )
DEFSPEC (FFEINTRIN_spec_OR_I,
    "or_i",
    FALSE,
    FFEINTRIN_familyF2C,
    FFEINTRIN_impIOR
  )
DEFSPEC (FFEINTRIN_spec_OR_L,
    "or_l",
    FALSE,
    FFEINTRIN_familyF2C,
    FFEINTRIN_imp_OR_L
  )
DEFSPEC (FFEINTRIN_spec_QEXT_C,
    "qext_c",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_QEXT_E,
    "qext_e",
    FALSE,
    FFEINTRIN_familyFVZ,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_QEXT_I,
    "qext_i",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_QEXT_J,
    "qext_j",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_QEXT_Q,
    "qext_q",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_QFLOAT_I,
    "qfloat_i",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_QFLOAT_J,
    "qfloat_j",
    FALSE,
    FFEINTRIN_familyVXT,
    FFEINTRIN_impNONE
  )
DEFSPEC (FFEINTRIN_spec_REAL_E,
    "real_e",
    FALSE,
    FFEINTRIN_familyFVZ,
    FFEINTRIN_imp_REAL_E
  )
DEFSPEC (FFEINTRIN_spec_RSHIFT_I,
    "rshift_i",
    FALSE,
    FFEINTRIN_familyF2C,
    FFEINTRIN_imp_RSHIFT_I
  )
DEFSPEC (FFEINTRIN_spec_RSHIFT_L,
    "rshift_l",
    FALSE,
    FFEINTRIN_familyF2C,
    FFEINTRIN_imp_RSHIFT_L
  )
DEFSPEC (FFEINTRIN_spec_XOR_I,
    "xor_i",
    FALSE,
    FFEINTRIN_familyF2C,
    FFEINTRIN_impIEOR
  )
DEFSPEC (FFEINTRIN_spec_XOR_L,
    "xor_l",
    FALSE,
    FFEINTRIN_familyF2C,
    FFEINTRIN_imp_XOR_L
  )
DEFSPEC (FFEINTRIN_specNONE,
    "none",
    FALSE,
    FFEINTRIN_familyNONE,
    FFEINTRIN_impNONE
  )
